#
# spec file for package python-towncrier
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-towncrier
Version:        23.11.0
Release:        1.2
Summary:        Building newsfiles for your project
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/hawkowl/towncrier
Source:         https://files.pythonhosted.org/packages/source/t/towncrier/towncrier-%{version}.tar.gz
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module importlib-resources}
BuildRequires:  %{python_module incremental}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       git-core
Requires:       python-Jinja2
Requires:       python-click
Requires:       python-importlib-resources
Requires:       python-incremental
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%if 0%{?python_version_nodots} < 311
Requires:       python-tomli
%endif
# SECTION test requirements
BuildRequires:  %{python_module Jinja2}
BuildRequires:  %{python_module Twisted}
BuildRequires:  %{python_module click}
BuildRequires:  %{python_module incremental}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module tomli}
BuildRequires:  git-core
# /SECTION
%python_subpackages

%description
Building newsfiles for your project.

%prep
%setup -q -n towncrier-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/towncrier
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export LANG=en_US.UTF-8
%pytest

%post
%python_install_alternative towncrier

%postun
%python_uninstall_alternative towncrier

%files %{python_files}
%doc NEWS.rst README.rst
%license LICENSE
%python_alternative %{_bindir}/towncrier
%{python_sitelib}/towncrier
%{python_sitelib}/towncrier-%{version}.dist-info

%changelog
* Tue Mar 19 2024 Dirk Müller <dmueller@suse.com>
- update to 23.11.0:
  * Fragments with filenames like fix-1.2.3.feature are now
    associated with the ticket fix-1.2.3. In previous versions
    they were incorrectly associated to ticket 3.
  * Orphan newsfragments containing numeric values are no longer
    accidentally associated to tickets. In previous versions the
    orphan marker was ignored and the newsfragment was associated
    to a ticket having the last numerical value from the
    filename.
  * No significant changes since the previous release candidate.
  * Python 3.12 is now officially supported. (#541)
  * Python 3.12 is now officially supported.
  * Initial support was added for monorepo-style setup. One
    project with multiple independent news files stored in
    separate sub-directories, that share the same towncrier
    config. (#548)
  * Initial support was added for monorepo-style setup. One
    project with multiple independent news files stored in
    separate sub-directories, that share the same towncrier
    config.
  * Two newlines are no longer always added between the current
    release notes and the previous content. The newlines are now
    defined only inside the template. Important! If you're using
    a custom template and want to keep the same whitespace
    between releases, you may have to modify your template.
    (#552)
  * Two newlines are no longer always added between the current
    release notes and the previous content. The newlines are now
    defined only inside the template.
  * The support for Python 3.7 has been dropped.
  * Provide a default Markdown template if the configured
    filename ends with .md.
  * Towncrier no longer depends on setuptools & uses
    importlib.resources (or its backport) instead. (#496)
  * Towncrier no longer depends on setuptools & uses
    importlib.resources (or its backport) instead.
  * Calling towncrier check without an existing configuration,
    will just show only an error message. In previous versions, a
    traceback was generated instead of the error message. (#501)
  * Calling towncrier check without an existing configuration,
    will just show only an error message.
  * In previous versions, a traceback was generated instead of
    the error message.
  * No changes since the previous release candidate.
  * Added --keep option to the build command that allows
    generating a newsfile, but keeps the newsfragments in place.
    This option can not be used together with --yes. (#129)
  * Added --keep option to the build command that allows
    generating a newsfile, but keeps the newsfragments in place.
    This option can not be used together with --yes.
  * Python 3.11 is now officially supported.
* Mon May 18 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Fri Dec 27 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v19.2.0
